@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Scalar::Util qw/blessed/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our (%ERROR, $caller);
 BEGIN {
@@ -13,6 +13,7 @@ BEGIN {
 		invalid_key => 'A miserable death %s - %s - %s',
 		invalid_index => 'A slightly more miserable death %s - %s - %s',
 		invalid_method => 'A horrible horrible miserable death %s - %s - %s',
+		allow_meth_keys => 'jump from a high building',
 	);
 }
 
@@ -81,24 +82,24 @@ sub _generate_params {
 	my ($string, $obj, @world, $current) = @_;
 	foreach ( split /(?![^\(\[\{]+[\]\}\)]),/, $string ) {
 		if ( $_ =~ m/^\s*\[\s*(.*)\]/ ) {
-			$current = _generate_params($1);
+			$current = _generate_params($1, $obj);
 			push @world, $current;
 		}
 		elsif ( $_ =~ m/^\s*\{\s*(.*)\s*\}/ ) {
 			$current = {};
 			my %temp = split '=>', $1;
-			do { $current->{_generate_params(sprintf "'%s'", $_)->[0]} = _generate_params($temp{$_})->[0] } for keys %temp;
+			do { $current->{_generate_params( defined $ERROR{allow_meth_keys} ? sprintf("'%s'", $_) : ($_, $obj))->[0] } = _generate_params($temp{$_}, $obj)->[0] } for keys %temp;
 			push @world, $current;
 		}
 		elsif ( ($_ =~ m/^\s*(\d+)\s*$/) || ($_ =~ m/^\s*[\'\"]+\s*(.*?)\s*[\'\"]+\s*$/) ) {
 			push @world, $1;
 		} 
 		else {
+			my $ex = $_ =~ s/^\s*\&//;
 			my ($method, $args) = $_ =~ /^\s*(.*?)\((.*)\)$/;
-			($method) = $_ =~ m/\s*(.*)\s*/ if ! $method;
-			push @world, $obj->$method($args ? @{ _generate_params($args, $obj) } : undef);
-			#my $pkg = ref $obj;
-			#push @world, $args ? sub { $obj->$method(@{ _generate_params($args, $obj) }) } : \&{"$pkg::$method"};
+			($method) = $_ =~ m/\s*(.*)\s*/ unless $method;
+			$args = $args ? _generate_params($args, $obj) : [];	
+			push @world, $ex ? do { no strict 'refs'; *{"${caller}::${method}"}->(@{ $args }); } : $obj->$method(@{ $args });
 		}
 	}
 	return \@world;
@@ -118,7 +119,7 @@ Data::LNPath - lookup on nested data via path
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -129,6 +130,7 @@ Version 0.02
 			invalid_key => \&invalid_key,
 			invalid_index => \&invalid_index,
 			invalid_method => \&invalid_method,,
+			allow_meth_keys => undef
 		} 
 	};
 
@@ -144,12 +146,14 @@ Version 0.02
 	};
 
 	lnpath($data, '/three'); # 10
-	lnpath($data, 'one/a/1'), # 10;
-	lnpath($data, 'one/b/a'), # 10
-	lnpath($data, 'two/2/3/4'), # 2 unless you set the additional error invalid_path (make it die)
-	lnpath($data, 'four/plus(10, 2)')
-	lnpath($data, 'four/minus(200, crazy_world)') # will create a reference
-	lnpath($data, 'four/plus(200, crazy_world(50))'), # will create a reference
+	lnpath($data, 'one/a/1'); # 10;
+	lnpath($data, 'one/b/a'); # 10
+	lnpath($data, 'two/2/3/4'); # 2 unless you set the additional error invalid_path (make it die)
+	lnpath($data, 'four/plus(10, 2)');
+	lnpath($data, 'four/minus(200, crazy_world)');
+	lnpath($data, 'four/plus(200, crazy_world(50))');
+	lnpath($data, 'four/plus(200, &other_world(100))');
+	lnpath($data, 'four/magic(200, { okay => 'fine' }, [ 1, 2, 3, should, &work ])');
 
 =head1 EXPORT
 
